@@ -350,7 +350,11 @@ _add_value_type_update (GString *str, const gchar *name, GValue *value, gboolean
 			} else {
 				g_warning ("_add_value_type_update: unhandled boxed value type (%s)", G_VALUE_TYPE_NAME (value));
 			}
-			break;	
+			break;
+
+		case G_TYPE_OBJECT:
+			/*do nothing, ignore */	
+			break;
 
 		default:
 			g_warning ("_add_value_type_update: unhandled value type (%s)", G_VALUE_TYPE_NAME (value));
@@ -662,6 +666,9 @@ __add_metadata_parameters (MidgardDBObject *dbobject, MidgardDBObjectClass *klas
 	GObject *object = (GObject *) MGD_DBOBJECT_METADATA (dbobject);
 
 	for (i = 0; i < n_prop; i++) {
+		/* Ignore property which holds object */
+		if (G_TYPE_FUNDAMENTAL (pspecs[i]->value_type) == G_TYPE_OBJECT)
+			continue;
 		const gchar *col_name = midgard_core_class_get_property_colname (MIDGARD_DBOBJECT_CLASS (mklass), pspecs[i]->name);
 		_SET_HOLDER_VALUE;
 	}
@@ -697,8 +704,9 @@ midgard_core_query_create_dbobject_record (MidgardDBObject *object)
 	GError *error = NULL;
 
 	for (i = 0; i < n_props; i++) {
-		/* Ignore primary key */
-		if (pk && g_str_equal (pspecs[i]->name, pk))
+		/* Ignore primary key and property of GObject type*/
+		if ((pk && g_str_equal (pspecs[i]->name, pk)) || 
+				G_TYPE_FUNDAMENTAL(pspecs[i]->value_type) == G_TYPE_OBJECT)
 			continue;
 
 		const gchar *col_name = midgard_core_class_get_property_colname (klass, pspecs[i]->name);
@@ -916,13 +924,17 @@ midgard_core_query_update_dbobject_record (MidgardDBObject *object)
 
 	MgdSchemaPropertyAttr *prop_attr = NULL;	
 	GValue value = {0, };
+	gboolean add_coma = FALSE;
 
 	for (i = 0; i < n_prop; i++) {
-	
+
 		/* Map property to storage field */
 		prop_attr = midgard_core_class_get_property_attr (klass, pspecs[i]->name);
-		if (!prop_attr || (prop_attr && !prop_attr->field))
+		if (!prop_attr || (prop_attr && !prop_attr->field)) {
+			if (i == 1)
+				add_coma = FALSE;
 			continue;
+		}
 
 		g_value_init (&value, pspecs[i]->value_type);
 		g_object_get_property (G_OBJECT (object), pspecs[i]->name, &value);
@@ -937,11 +949,13 @@ midgard_core_query_update_dbobject_record (MidgardDBObject *object)
 			g_value_set_uint (&value, bv ? 1 : 0);
 		}*/
 
-		_add_value_type_update (sql, (const gchar *) prop_attr->field, &value, i > 0 ? TRUE : FALSE);
+		_add_value_type_update (sql, (const gchar *) prop_attr->field, &value, add_coma);
 		g_value_unset (&value);
+
+		add_coma = TRUE;
 	}
 
-	g_string_append_printf (sql, " WHERE %s.guid = '%s'", table, guid);  	
+	g_string_append_printf (sql, " WHERE %s.guid = '%s'", table, guid);  		
 
 	/* Create statement and set parameters */
 	GdaSqlParser *parser = (MGD_OBJECT_CNC (object))->priv->parser;
@@ -977,7 +991,7 @@ midgard_core_query_update_dbobject_record (MidgardDBObject *object)
 		prop_attr = midgard_core_class_get_property_attr (klass, pspecs[i]->name);
 		if (!prop_attr || (prop_attr && !prop_attr->field))
 			continue;
-
+	
 		const gchar *prop_field = prop_attr->field;
 
 		p = gda_set_get_holder (params, prop_field);
@@ -1376,7 +1390,7 @@ midgard_core_query_insert_records (MidgardConnection *mgd,
 	GList *cl, *vl;
 
 	for (cl = cols, vl = values; cl != NULL; cl = cl->next, vl = vl->next) {
-
+	
 		_add_value_type_update (sql, (const gchar *) cl->data, (GValue *) vl->data, i > 0 ? TRUE : FALSE);
 		i++;
 	}
@@ -2976,7 +2990,7 @@ __compute_reserved_property_constraint (Psh *holder, const gchar *token_1, const
 		const gchar *target_property = midgard_reflection_property_get_link_target (mrp, token_1);
 		holder->target_colname = midgard_core_class_get_property_colname (MIDGARD_DBOBJECT_CLASS (holder->klass), target_property);
 		holder->target_table = midgard_core_class_get_table (MIDGARD_DBOBJECT_CLASS (holder->klass));
-		holder->target_table_alias = g_strdup_printf ("t%d", ++holder->executor->priv->tableid);;
+		holder->target_table_alias = g_strdup_printf ("t%d", ++holder->executor->priv->tableid);
 		__add_join (holder);
 		holder->table = holder->target_table;
 		holder->table_alias = holder->target_table_alias;
@@ -2994,7 +3008,7 @@ midgard_core_query_compute_constraint_property (MidgardQueryExecutor *executor,
 
 	/* Set table alias if it's not set */
 	if (storage)
-		MQE_SET_TABLE_ALIAS (executor, storage->priv->table_alias);
+		MQE_SET_TABLE_ALIAS (executor, storage);
 
 	gchar *table_field = NULL;
 	gchar *table_alias = executor->priv->table_alias;
@@ -3017,6 +3031,11 @@ midgard_core_query_compute_constraint_property (MidgardQueryExecutor *executor,
 	/* case: property */
 	if (i == 1) {
 		const gchar *property_field = midgard_core_class_get_property_colname (klass, name);
+		if (!property_field) {
+			g_warning ("%s doesn't seem to be registered for %s", name, G_OBJECT_CLASS_NAME (klass));
+			g_strfreev (spltd);
+			return NULL;
+		}
 		table_field = g_strdup_printf ("%s.%s", table_alias, property_field);
 	} else if (i < 4) {
 		/* Set all pointers we need to generate valid tables' names, aliases or joins */
