@@ -22,7 +22,6 @@
 #include <libxml/parserInternals.h>
 #include "midgard_metadata.h"
 #include "midgard_timestamp.h"
-#include "midgard_object_class.h"
 #include "midgard_core_object.h"
 #include "schema.h"
 #include "midgard_core_metadata.h"
@@ -30,130 +29,130 @@
 
 void __set_from_xml_node(MidgardDBObject *object, xmlNode *node);
 
-static void _action_create_callback(MgdObject *object, gpointer ud)
+static void 
+_action_create_callback (MidgardObject *object, gpointer ud)
 {
 	MidgardMetadata *mdata = (MidgardMetadata *) ud;
 
 	gchar *person_guid = "";
-	MidgardConnection *mgd = MGD_OBJECT_CNC(object);
-	MidgardUser *user = midgard_connection_get_user(mgd);
+	MidgardConnection *mgd = MGD_OBJECT_CNC (object);
+	MidgardObject *person = MGD_CNC_PERSON (mgd);
 
-	if (user) {
-		const MgdObject *person = midgard_user_get_person(user);
-
-		if (person) {
-			if (G_IS_OBJECT(G_OBJECT(person)))
-				person_guid = (gchar *)MGD_OBJECT_GUID(person);			
-		}
-	}
-
-
-	GValue *tval = midgard_timestamp_new_current();
+	if (person) 
+		person_guid = (gchar *)MGD_OBJECT_GUID (person);			
 	
 	/* set creator */
-	midgard_core_metadata_set_creator(mdata, person_guid);
+	GValue rval = {0, };
+	g_value_init (&rval, G_TYPE_STRING);
+	g_value_set_string (&rval, person_guid);
+	/* set creator */
+	midgard_core_metadata_set_creator (mdata, (const GValue *)&rval);
+	/* set revisor */
+	midgard_core_metadata_set_revisor (mdata, (const GValue *)&rval);
+	g_value_unset (&rval);
 
-	/* set created */	
-	midgard_core_metadata_set_created(mdata, tval);
+	/* set created */
+	midgard_core_timestamp_set_current_time (mdata->priv->created);
 
 	/* set revised */	
-	midgard_core_metadata_set_revised(mdata, tval);
+	midgard_core_timestamp_set_current_time (mdata->priv->revised);
 
 	/* set revision */
-	midgard_core_metadata_set_revision(mdata, 0);
+	GValue rev_val = {0, };
+	g_value_init (&rev_val, G_TYPE_UINT);
+	g_value_set_uint (&rev_val, 0);
+	midgard_core_metadata_set_revision (mdata, (const GValue *)&rev_val);
+	g_value_unset (&rev_val);
 
-	/* set revisor */
-	midgard_core_metadata_set_revisor(mdata, person_guid);
-	
-	g_value_unset(tval);
-	g_free (tval); 
+	/* set default values */
+	mdata->priv->locker = g_strdup ("");
+	mdata->priv->approver = g_strdup ("");
+
+	if (!mdata->priv->authors)
+		mdata->priv->authors = g_strdup ("");
+	if (!mdata->priv->owner)
+		mdata->priv->owner = g_strdup ("");
 }
 
-static void _action_update_callback(MgdObject *object, gpointer ud)
+static void 
+_action_update_callback (MidgardObject *object, gpointer ud)
 {
 	MidgardMetadata *mdata = (MidgardMetadata *) ud;
 	
 	gchar *person_guid = "";
 	MidgardConnection *mgd = MGD_OBJECT_CNC(object);
-	MidgardUser *user = midgard_connection_get_user(mgd);
+	MidgardObject *person = MGD_CNC_PERSON (mgd);
 
-	if (user) {
-		const MgdObject *person = midgard_user_get_person(user);
-
-		if (person) {
-			if (G_IS_OBJECT(G_OBJECT(person)))
-				person_guid = (gchar *)MGD_OBJECT_GUID(person);			
-		}
-	}
-
-	GValue *tval = midgard_timestamp_new_current();
+	if (person) 
+		person_guid = (gchar *)MGD_OBJECT_GUID(person);			
 
 	/* set revisor */
-	midgard_core_metadata_set_revisor(mdata, person_guid);
+	GValue rval = {0, };
+	g_value_init (&rval, G_TYPE_STRING);
+	g_value_set_string (&rval, person_guid);
+	midgard_core_metadata_set_revisor (mdata, (const GValue *)&rval);
+	g_value_unset (&rval);
 
 	/* set revised */
-	midgard_core_metadata_set_revised(mdata, tval);
+	GValue tval = {0, };
+	midgard_timestamp_new_current (&tval);
+	midgard_core_metadata_set_revised (mdata, (const GValue *)&tval);	
+	g_value_unset (&tval);
+
+	GValue _val = {0, };
+	g_value_init (&_val, MIDGARD_TYPE_TIMESTAMP);
+	g_object_get_property (G_OBJECT (mdata), "revised", &_val);
 
 	/* set revision */
-	midgard_core_metadata_increase_revision(mdata);
-	
-	g_value_unset(tval);	
-	g_free (tval);
+	midgard_core_metadata_increase_revision (mdata);
 }
 
-static void _action_delete_callback(MgdObject *object, gpointer ud)
+static void 
+_action_delete_callback(MidgardObject *object, gpointer ud)
 {
 	return;
 }
 
-static void _action_import_callback(MgdObject *object, gpointer ud)
+static void 
+_action_import_callback(MidgardObject *object, gpointer ud)
 {
 	MidgardMetadata *mdata = (MidgardMetadata *) ud;	
-	GValue *tval = midgard_timestamp_new_current();
-
-	/* set imported */
-	midgard_core_metadata_set_imported (mdata, tval);
-	
-	g_value_unset (tval);
-	g_free (tval);
+	midgard_core_timestamp_set_current_time (mdata->priv->imported);
 }
 
-static void _action_export_callback(MgdObject *object, gpointer ud)
+static void 
+_action_export_callback(MidgardObject *object, gpointer ud)
 {
 	MidgardMetadata *mdata = (MidgardMetadata *) ud;	
-	const GValue *tval = (GValue *)midgard_timestamp_new_current();
 
 	/* This is backward "compatible" defaults set.
 	 * It's done in case when some old object has been never
 	 * touched by new API */
 	if (!mdata->priv->revised && !mdata->priv->created) {
-		midgard_core_metadata_set_created(mdata, tval);
-		midgard_core_metadata_set_revised(mdata, tval);
+		midgard_core_timestamp_set_current_time (mdata->priv->created);
+		midgard_core_timestamp_set_current_time (mdata->priv->revised);
 	}
 
 	if (!mdata->priv->revised && mdata->priv->created) {
-		midgard_core_metadata_set_created(mdata, tval);
+		midgard_core_timestamp_set_current_time (mdata->priv->created);
 		midgard_core_metadata_increase_revision(mdata);
 	}
 
 	if (!mdata->priv->created && mdata->priv->revised) {
-		midgard_core_metadata_set_created(mdata, tval);
+		midgard_core_timestamp_set_current_time (mdata->priv->created);
 	}
 		
 	/* set exported */
-	midgard_core_metadata_set_exported(mdata, tval);
-
-	g_value_unset ((GValue *)tval);
-	g_free ((GValue *)tval);
+	midgard_core_timestamp_set_current_time (mdata->priv->exported);
 }
 
 /**
  * midgard_metadata_new:
- * @object: #MgdObject for which metadata is created
+ * @object: #MidgardObject for which metadata is created
  * 
- * Creates new midgard_metadata instance for the given #MgdObject instance.
+ * Creates new midgard_metadata instance for the given #MidgardObject instance.
  *
- * Do not use g_object_new() as metadata constructor. #MgdObject pointer is internally 
+ * Do not use g_object_new() as metadata constructor. #MidgardObject pointer is internally 
  * assigned as a pointer to midgard object for which particular metadata object 
  * instance was created.
  * 
@@ -163,37 +162,153 @@ static void _action_export_callback(MgdObject *object, gpointer ud)
  * keep value of such property "as is".  
  *
  * Do not free #MidgardMetadata object's memory as it is automatically
- * freed when particular #MgdObject object's instance memory is freed. 
+ * freed when particular #MidgardObject object's instance memory is freed. 
  *
  * Returns: newly allocated midgard_metadata instance
  */ 
-MidgardMetadata *midgard_metadata_new(MgdObject *object)
+MidgardMetadata *
+midgard_metadata_new (MidgardDBObject *object)
 {
-	g_assert(object != NULL);
+	g_return_val_if_fail (object != NULL, NULL);
 	
 	MidgardMetadata *self = 
-		(MidgardMetadata *) g_object_new(MIDGARD_TYPE_METADATA, NULL);
+		(MidgardMetadata *) g_object_new (MIDGARD_TYPE_METADATA, NULL);
 
-	g_signal_connect(G_OBJECT(object), "action-create",
-			G_CALLBACK(_action_create_callback), self);
+	g_signal_connect (G_OBJECT (object), "action-create",
+			G_CALLBACK (_action_create_callback), self);
 
-	g_signal_connect(G_OBJECT(object), "action-update",
-			G_CALLBACK(_action_update_callback), self);
+	g_signal_connect (G_OBJECT (object), "action-update",
+			G_CALLBACK (_action_update_callback), self);
 
-	g_signal_connect(G_OBJECT(object), "action-delete", 
-			G_CALLBACK(_action_delete_callback), self);
+	g_signal_connect (G_OBJECT (object), "action-delete", 
+			G_CALLBACK (_action_delete_callback), self);
 
-	g_signal_connect(G_OBJECT(object), "action-import", 
-			G_CALLBACK(_action_import_callback), self);
+	g_signal_connect (G_OBJECT (object), "action-import", 
+			G_CALLBACK (_action_import_callback), self);
 
-	g_signal_connect(G_OBJECT(object), "action-export", 
-			G_CALLBACK(_action_export_callback), self);
+	g_signal_connect (G_OBJECT (object), "action-export", 
+			G_CALLBACK (_action_export_callback), self);
 
 	self->priv->object = object;
 
 	return self;
 }
 
+void 
+_midgard_metadata_set_from_data_model (MidgardDBObject *self, GdaDataModel *model, gint row)
+{
+	g_return_if_fail (self != NULL);
+	g_return_if_fail (model != NULL);
+	g_return_if_fail (row > -1);
+
+	MidgardDBObject *dbobject = MIDGARD_DBOBJECT (MIDGARD_METADATA (self)->priv->object);
+	MgdSchemaTypeAttr *type_attr = MIDGARD_DBOBJECT_GET_CLASS (dbobject)->dbpriv->storage_data;
+	MidgardMetadata *metadata = MIDGARD_METADATA (self);
+
+	/* ignore metadata and action properties so decrease properties count */
+	guint n_props = type_attr->class_nprop - 2;
+	if (n_props< 1) {
+		g_warning ("Expected positive number of properties for given %s class", G_OBJECT_TYPE_NAME (G_OBJECT (dbobject)));
+		return;
+	}
+
+	/* creator */
+	const GValue *val = gda_data_model_get_value_at (model, n_props, row, NULL);
+	midgard_core_metadata_set_creator (metadata, (GValue *) val);
+
+	/* created */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_created (metadata, val);
+
+	/* revisor */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_revisor (metadata, val);
+
+	/* revised */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_revised (metadata, val);
+	
+	/* revision */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_revision (metadata, val);
+	
+	/* locker */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_locker (metadata, val);
+
+	/* locked */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_locked (metadata, val);
+
+	/* approver */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_approver (metadata, val);
+
+	/* approved */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_approved (metadata, val);
+
+	/* authors */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_authors (metadata, val);
+
+	/* owner */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_owner (metadata, val);
+
+	/* schedule_start */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_schedule_start (metadata, val);
+
+	/* schedule_end */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_schedule_end (metadata, val);
+
+	/* hidden */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_hidden (metadata, val);
+
+	/* navnoentry */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_navnoentry (metadata, val);
+
+	/* size */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_size (metadata, val);
+
+	/* published */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_published (metadata, val);
+
+	/* score */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_score (metadata, val);
+
+	/* imported */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_imported (metadata, val);
+
+	/* exported */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_exported (metadata, val);
+
+	/* deleted */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_deleted (metadata, val);
+
+	/* isapproved */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_isapproved (metadata, val);
+
+	/* islocked */
+	val = gda_data_model_get_value_at (model, ++n_props, row, NULL);
+	midgard_core_metadata_set_islocked (metadata, val);
+}
+
+/* GOBJECT ROUTINES */
+
+static GObjectClass *__parent_class = NULL;
+
 enum {
     MIDGARD_METADATA_CREATOR = 1,
     MIDGARD_METADATA_CREATED,
@@ -270,17 +385,35 @@ _metadata_set_property (GObject *object, guint property_id,
 			break;                  
 	}
 }
-    
+
+gboolean
+_midgard_metadata_dbpriv_get_property (MidgardDBObject *self, const gchar *name, GValue *value)
+{
+	gchar *datamodel_property = g_strconcat ("metadata_", name, NULL);
+	MidgardDBObject *dbobject = MIDGARD_METADATA(self)->priv->object;
+
+	if (!dbobject || !dbobject->dbpriv)
+		return FALSE;
+
+	gboolean rv = MIDGARD_DBOBJECT_CLASS (__parent_class)->dbpriv->get_property (dbobject, datamodel_property, value);
+	g_free (datamodel_property);
+
+	return rv;
+}
+
 static void
 _metadata_get_property (GObject *object, guint property_id,
         GValue *value, GParamSpec *pspec)
 {    
 	MidgardMetadata *self =	(MidgardMetadata *) object;
-	
+
+	if (MIDGARD_DBOBJECT_GET_CLASS (object)->dbpriv->get_property (MIDGARD_DBOBJECT (object), pspec->name, value))
+		return;
+
 	switch (property_id) {
 		
-		case MIDGARD_METADATA_CREATOR: 
-			g_value_set_string (value, self->priv->creator);
+		case MIDGARD_METADATA_CREATOR:
+			g_value_set_string (value, self->priv->creator);	
 			break;
 			
 		case MIDGARD_METADATA_CREATED:
@@ -377,8 +510,6 @@ _metadata_get_property (GObject *object, guint property_id,
 	}
 }
 
-static GObjectClass *__parent_class = NULL;
-
 static GObject *
 _metadata_constructor (GType type, guint n_construct_properties,
 			GObjectConstructParam *construct_properties)
@@ -402,29 +533,29 @@ static void
 _metadata_instance_init(GTypeInstance *instance, gpointer g_class) 
 {	
 	MidgardMetadata *self = (MidgardMetadata *)instance;
-	
+
 	/* allocate private data */
 	self->priv = g_new(MidgardMetadataPrivate, 1);
 	self->priv->creator = NULL;
-	self->priv->created = NULL;
-	self->priv->revised = NULL;
+	self->priv->created = midgard_timestamp_new();
+	self->priv->revised = midgard_timestamp_new();
 	self->priv->revisor = NULL;
 	self->priv->locker = NULL;
-	self->priv->locked = NULL;
-	self->priv->approved = NULL;
+	self->priv->locked = midgard_timestamp_new();
+	self->priv->approved = midgard_timestamp_new();
 	self->priv->approver = NULL;
 	self->priv->authors = NULL;
 	self->priv->owner = NULL;
 	self->priv->revision = 0;
-	self->priv->schedule_start = NULL;
-	self->priv->schedule_end = NULL;
+	self->priv->schedule_start = midgard_timestamp_new();
+	self->priv->schedule_end = midgard_timestamp_new();
 	self->priv->hidden = FALSE;
 	self->priv->nav_noentry = FALSE;
 	self->priv->size = 0;
-	self->priv->published = NULL;
+	self->priv->published = midgard_timestamp_new();
 	self->priv->score = 0;
-	self->priv->exported = NULL;
-	self->priv->imported = NULL;
+	self->priv->exported = midgard_timestamp_new();
+	self->priv->imported = midgard_timestamp_new();
 	self->priv->deleted = FALSE;
 
 	self->priv->lock_is_set = FALSE;
@@ -439,7 +570,7 @@ _metadata_object_finalize(GObject *object)
 {
 	g_assert(object);
 
-	MidgardMetadata *self = (MidgardMetadata *)object;
+	MidgardMetadata *self = (MidgardMetadata *)object;	
 
 	/* Free private data */
 	g_free(self->priv->creator);
@@ -463,40 +594,6 @@ _metadata_object_finalize(GObject *object)
 	__parent_class->finalize (object);
 }
 
-/* Set properties when object is created */
-void midgard_metadata_set_create(MgdObject *object)
-{
-	MgdObject *person = (MgdObject *)object->dbpriv->mgd->person;
-	gchar *person_guid;
-	g_object_get(G_OBJECT(person), "guid", &person_guid, NULL);
-	
-	MidgardMetadata *metadata = (MidgardMetadata *) object->metadata;
-	
-	midgard_core_metadata_set_creator(metadata, person_guid);
-	g_free(person_guid);
-
-	GValue *tval = midgard_timestamp_new_current();
-	midgard_core_metadata_set_created(metadata, tval);
-	g_value_unset(tval);
-}
-
-/* Set properties when object is updated */
-void midgard_metadata_set_update(MgdObject *object)
-{
-	MgdObject *person = (MgdObject *)object->dbpriv->mgd->person;
-	gchar *person_guid;
-	g_object_get(G_OBJECT(person), "guid", &person_guid, NULL);
-
-	MidgardMetadata *metadata = (MidgardMetadata *) object->metadata;
-	
-	midgard_core_metadata_set_revisor(metadata, person_guid);
-	g_free(person_guid);
-
-	GValue *tval = midgard_timestamp_new_current();
-	midgard_core_metadata_set_revised(metadata, tval);
-	g_value_unset(tval);
-}
-
 /* Initialize class */
 static void
 _metadata_class_init (gpointer g_class, gpointer g_class_data)
@@ -512,31 +609,6 @@ _metadata_class_init (gpointer g_class, gpointer g_class_data)
 	gobject_class->dispose = _metadata_dispose;
 	gobject_class->finalize = _metadata_object_finalize;
 
-	/* Register signals */
-	/* Create signal which should be emitted before MgdObject is created */
-	klass->set_created = midgard_metadata_set_create;
-	klass->signal_set_created = g_signal_new("set_created",
-			G_TYPE_FROM_CLASS(g_class),
-			G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
-			G_STRUCT_OFFSET (MidgardMetadataClass, set_created),
-			NULL, /* accumulator */
-			NULL, /* accu_data */
-			NULL, /* marshaller */
-			G_TYPE_NONE,
-			0);
-    
-	/* Create signal which should be emitted before MgdObject is updates */
-	klass->set_updated = midgard_metadata_set_update;
-	klass->signal_set_updated = g_signal_new("set_updated",
-			G_TYPE_FROM_CLASS(g_class),
-			G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
-			G_STRUCT_OFFSET (MidgardMetadataClass, set_updated),
-			NULL, /* accumulator */
-			NULL, /* accu_data */
-			NULL, /* marshaller */
-			G_TYPE_NONE,
-			0);
-
 	MgdSchemaPropertyAttr *prop_attr;
 	MgdSchemaTypeAttr *type_attr = midgard_core_schema_type_attr_new();
 	
@@ -954,9 +1026,15 @@ _metadata_class_init (gpointer g_class, gpointer g_class_data)
 			g_strdup((gchar *)"islocked"), prop_attr);
 
 	/* Initialize private member */
-	klass->dbpriv = g_new(MidgardDBObjectPrivate, 1);
-	klass->dbpriv->storage_data = type_attr;
-	klass->dbpriv->set_from_xml_node = __set_from_xml_node;
+	MidgardDBObjectClass *dbklass = MIDGARD_DBOBJECT_CLASS (klass);
+	dbklass->dbpriv = g_new(MidgardDBObjectPrivate, 1);
+	dbklass->dbpriv->storage_data = type_attr;
+	dbklass->dbpriv->set_from_xml_node = __set_from_xml_node;
+	dbklass->dbpriv->add_fields_to_select_statement = NULL;
+	dbklass->dbpriv->has_metadata = FALSE;
+	dbklass->dbpriv->get_property = _midgard_metadata_dbpriv_get_property;
+	dbklass->dbpriv->set_property = midgard_core_metadata_dbpriv_set_property;
+	dbklass->dbpriv->set_from_data_model = _midgard_metadata_set_from_data_model;
 }
 
 GType midgard_metadata_get_type (void)
@@ -974,22 +1052,11 @@ GType midgard_metadata_get_type (void)
 			0,      /* n_preallocs */
 			_metadata_instance_init    /* instance_init */
 		};
-		type = g_type_register_static (MIDGARD_TYPE_DBOBJECT,
-				"midgard_metadata",
-				&info, 0);
+		type = g_type_register_static (MIDGARD_TYPE_DBOBJECT, "MidgardMetadata", &info, 0);
 	}
 	return type;
 }
 
-MidgardMetadata *midgard_object_metadata_get(MgdObject *object){
-
-    MidgardMetadata *mm = midgard_metadata_new(object);
-    if(mm)
-        return mm;
-
-    return NULL;
-}
-
 xmlNode *__metadata_lookup_node(xmlNode *node, const gchar *name)
 {
 	xmlNode *cur = NULL;
@@ -998,7 +1065,7 @@ xmlNode *__metadata_lookup_node(xmlNode *node, const gchar *name)
 		
 		if (cur->type == XML_ELEMENT_NODE) {
 			
-			if(g_str_equal(cur->name, name))
+			if (g_str_equal (cur->name, name))
 					return cur;
 		}
 	}
@@ -1030,23 +1097,24 @@ gchar *__get_node_content_string(xmlNode *node)
 	return (gchar*)decoded;
 }
 
-void __set_date_from_node(xmlNode *node,  MidgardTimestamp **date)
+void __set_date_from_node (xmlNode *node, MidgardTimestamp **date)
 {
-	if(!node)
+	if (!node)
 		return;
 
 	gchar *content = NULL;
-	content = (gchar *)xmlNodeGetContent(node);
+	content = (gchar *)xmlNodeGetContent (node);
 
 	if (content == NULL) {
-		g_warning("Can not handle NULL date for datetime property");
+		g_warning ("Can not handle NULL date for datetime property");
 		return;
 	}
 
 	if (*date != NULL)
-		g_free(*date);
+		g_free (*date);
 
-	*date = midgard_timestamp_new_from_iso8601(content);
+	*date = midgard_timestamp_new_from_iso8601 (content);
+	xmlFree (content);
 	
 	return;
 }
